package com.akamai.media.demo4;


import android.os.Bundle;
import android.preference.CheckBoxPreference;
import android.preference.EditTextPreference;
import android.preference.ListPreference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceCategory;
import android.preference.PreferenceScreen; 

public class PlayerConfiguration extends PreferenceActivity 
{
	public static final String PREFS_MAX_BITRATE = "PREFS_MAX_BITRATE";
	public static final String PREFS_AUTO_SWITCHING = "PREFS_AUTO_SWITCHING";
	public static final String PREFS_HLS_START_ALGORITHM = "PREFS_HLS_START_ALGORITHM";
	public static final String PREFS_NETSESSION_MODE = "PREFS_NETSESSION_MODE";
	public static final String PREFS_AUTO_BUFFER_MODE = "PREFS_AUTO_BUFFER_MODE";
	public static final String PREFS_BUFFER_SIZE = "PREFS_BUFFER_SIZE";
	public static final String PREFS_USE_START_BUFFER = "PREFS_USE_START_BUFFER";
	public static final String PREFS_PLAYER_WORKING_MODE = "PREFS_PLAYER_WORKING_MODE";
	public static final String PREFS_USE_MULTITHREAD = "PREFS_USE_MULTITHREAD";
	
	public static final String PREFS_MAX_BITRATE_DEFAULT_VALUE = "3000000";
	public static final String PREFS_NETSESSION_MODE_DEFAULT_VALUE = "0";
	public static final String PREFS_HLS_START_ALGORITHM_DEFAULT_VALUE = "1";
	public static final String PREFS_BUFFER_SIZE_DEFAULT_VALUE = "256";
	
	@Override
    protected void onCreate(Bundle savedInstanceState) 
        {
        super.onCreate(savedInstanceState);
        
        setPreferenceScreen(createPreferenceHierarchy());
    }

    private PreferenceScreen createPreferenceHierarchy() 
    {
        // Root
        PreferenceScreen root = getPreferenceManager().createPreferenceScreen(this);
        
        // Inline preferences 
        PreferenceCategory inlinePrefCat = new PreferenceCategory(this);
        inlinePrefCat.setTitle("General");
        root.addPreference(inlinePrefCat);
        
        // List preference
        ListPreference modePref = new ListPreference(this);
        modePref.setEntries(R.array.playerWorkingModeTypes);
        modePref.setDefaultValue("10"); //AUTO
        modePref.setEntryValues(R.array.playerWorkingModes_values);
        modePref.setDialogTitle("Decoding method");
        modePref.setKey(PREFS_PLAYER_WORKING_MODE);
        modePref.setTitle("Decoding method");
        modePref.setSummary("Audio/Video decoding method: auto, software, hardware, hardware adv");
        inlinePrefCat.addPreference(modePref);
        
        ListPreference netsessionPref = new ListPreference(this);
        netsessionPref.setEntries(R.array.netSessionMode);
        netsessionPref.setDefaultValue(PREFS_NETSESSION_MODE_DEFAULT_VALUE);
        netsessionPref.setEntryValues(R.array.netSessionMode_values);
        netsessionPref.setDialogTitle("Netsession Mode");
        netsessionPref.setKey(PREFS_NETSESSION_MODE);
        netsessionPref.setTitle("Netsession mode");
        netsessionPref.setSummary("Netsession configuration");
        inlinePrefCat.addPreference(netsessionPref);       
        
        PreferenceCategory inlinePrefBitrateCat = new PreferenceCategory(this);
        inlinePrefBitrateCat.setTitle("Bitrate Selection Options");
        root.addPreference(inlinePrefBitrateCat);
        
        ListPreference hlsStartingPref = new ListPreference(this);
        hlsStartingPref.setEntries(R.array.hlsStartingAlgorithm);
        hlsStartingPref.setDefaultValue(PREFS_HLS_START_ALGORITHM_DEFAULT_VALUE);
        hlsStartingPref.setEntryValues(R.array.hlsStartingAlgorithm_values);
        hlsStartingPref.setDialogTitle("Starting bitrate selection");
        hlsStartingPref.setKey(PREFS_HLS_START_ALGORITHM);
        hlsStartingPref.setTitle("Starting bitrate selection");
        hlsStartingPref.setSummary("Algorithm for selecting the initial bitrate");
        inlinePrefBitrateCat.addPreference(hlsStartingPref);
        
        EditTextPreference maxBitrate = new EditTextPreference(this);
        maxBitrate.setKey(PREFS_MAX_BITRATE);
        maxBitrate.setDefaultValue(PREFS_MAX_BITRATE_DEFAULT_VALUE);
        maxBitrate.setTitle("Max. Bitrate");
        maxBitrate.setSummary("Maximum bitrate to be used by the player");
        maxBitrate.setPersistent(true);
        maxBitrate.getEditText().setRawInputType(android.text.InputType.TYPE_CLASS_NUMBER);
        inlinePrefBitrateCat.addPreference(maxBitrate);
        
        CheckBoxPreference manualSwitching = new CheckBoxPreference(this);
        manualSwitching.setKey(PREFS_AUTO_SWITCHING);
        manualSwitching.setDefaultValue(true);
        manualSwitching.setTitle("Automatic bitrate switching");
        manualSwitching.setSummary("Automatic/Manual bitrate switching");
        manualSwitching.setPersistent(true);
        inlinePrefBitrateCat.addPreference(manualSwitching);
        
        PreferenceCategory inlinePrefbuffCat = new PreferenceCategory(this);
        inlinePrefbuffCat.setTitle("Buffer");
        root.addPreference(inlinePrefbuffCat);
        
        EditTextPreference bufferSize = new EditTextPreference(this);
        bufferSize.setKey(PREFS_BUFFER_SIZE);
        bufferSize.setDefaultValue(PREFS_BUFFER_SIZE_DEFAULT_VALUE);
        bufferSize.setTitle("Buffer Size");
        bufferSize.setSummary("Buffer size in Kilobytes");
        bufferSize.setPersistent(true);
        bufferSize.getEditText().setRawInputType(android.text.InputType.TYPE_CLASS_NUMBER);
        inlinePrefbuffCat.addPreference(bufferSize);
        
        CheckBoxPreference autoBuffer = new CheckBoxPreference(this);
        autoBuffer.setKey(PREFS_AUTO_BUFFER_MODE);
        autoBuffer.setDefaultValue(true);
        autoBuffer.setTitle("Use auto buffer size");
        autoBuffer.setSummary("Smart algorithm for getting the optimal buffer size");
        autoBuffer.setPersistent(true);
        inlinePrefbuffCat.addPreference(autoBuffer);
        
        CheckBoxPreference startBuffer = new CheckBoxPreference(this);
        startBuffer.setKey(PREFS_USE_START_BUFFER);
        startBuffer.setDefaultValue(true);
        startBuffer.setTitle("Enable fast start");
        startBuffer.setSummary("If enabled, playback starts as soon as possible. Otherwise data buffering will occur before starting the playback");
        startBuffer.setPersistent(true);
        inlinePrefbuffCat.addPreference(startBuffer);
        
        PreferenceCategory inlinePrefAdvCat = new PreferenceCategory(this);
        inlinePrefAdvCat.setTitle("Advanced");
        root.addPreference(inlinePrefAdvCat);
        
        CheckBoxPreference useMultithread = new CheckBoxPreference(this);
        useMultithread.setKey(PREFS_USE_MULTITHREAD);
        useMultithread.setDefaultValue(false);
        useMultithread.setTitle("Multithread decoding");
        useMultithread.setSummary("Use multiple threads to improve decoding performance");
        useMultithread.setPersistent(true);
        inlinePrefAdvCat.addPreference(useMultithread);
  
        return root;
    }
}
