package com.akamai.media.demo4;

import com.akamai.media.VideoPlayerView;


import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ListActivity;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.text.ClipboardManager;
import android.text.InputType;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.ViewGroup;
import android.view.Window;
import android.view.View;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.ListView;
import android.widget.ResourceCursorAdapter;
import android.widget.TextView;


public class PlayerView extends ListActivity
{
	private PlayerVideosDB mDB;
	private Cursor mCursor;   
	
	private static final int ACTIVITY_PREFS = 1;
	
	private static final int MenuAdd = Menu.FIRST + 1;
	private static final int MenuPlay = Menu.FIRST + 2;
	private static final int MenuDelete = Menu.FIRST + 3;
	private static final int MenuCopyUrl = Menu.FIRST + 4;
	private static final int MenuAbout = Menu.FIRST + 5;
	private static final int MenuConfig = Menu.FIRST + 6;
    private static final int DIALOG_ADD_ID = 1;
    private static final int DIALOG_PLAYLAST_ALERT_ID = 2;
    private static final int DIALOG_ABOUT_ID = 3;

    
    private String mLastUrlAdded = "";
	
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState)
    {
    	requestWindowFeature(Window.FEATURE_NO_TITLE);
    	
    	super.onCreate(savedInstanceState);  
    	setContentView(R.layout.main);
    	
    	mDB = new PlayerVideosDB(this);
    	mDB.open();
       	
    	// Configure the render object
    	final Intent intent = getIntent();

        // Do some setup based on the action being performed.
        final String action = intent.getAction();
        if (Intent.ACTION_VIEW.equals(action)) 
        {
        	//Intent oIntent = new Intent(PlayerView.this, PlayerViewActivity.class);
        	Intent oIntent = new Intent(PlayerView.this, PlayerVideoActivity.class);
        	Bundle oBundle = new Bundle();
        	oBundle.putString("url", intent.getData().toString());
        	oIntent.putExtras(oBundle);
        	
        	PlayerView.this.startActivity(oIntent);
        	finish();
        	return;
        }
        
        getListView().setOnCreateContextMenuListener(this);
    }
    
    
    @Override  
    protected void onPause() 
    {
        super.onPause();   
  
    }
    
    @Override  
    protected void onResume() 
    {	
        super.onResume();
        
        refreshData();
    }

    private void refreshData()
    {
    	if(mCursor == null)
    	{
    		mCursor = mDB.getAllEntries();
    		
    		if (mCursor != null) 
            {   
    			CustomAdapter adapter = new CustomAdapter(this, mCursor);
                setListAdapter(adapter);
                startManagingCursor(mCursor);
            }
    	}   
    	else
    	{
    		mCursor.requery();
    		startManagingCursor(mCursor);
    		//CustomAdapter adapter = new CustomAdapter(this, mCursor);
    		//setListAdapter(adapter);
    	}
    }
    
    
    
    private void addNewUrl(String url)
    {
    	VideoObject obj = new VideoObject();
    	obj.mUrl = url;
    	 
    	if(url.contains("/"))
    		obj.mName = url.substring(url.lastIndexOf("/") + 1);
    	else
    		obj.mName = url;
    	
    	mDB.insertEntry(obj);
    	refreshData();
    	
    	mLastUrlAdded = url;
    	
    	showDialog(DIALOG_PLAYLAST_ALERT_ID);
    }
    
    private void playUrl(String url)
    {
    	Intent intent;
    	intent = new Intent(PlayerView.this, PlayerVideoActivity.class);
		intent.putExtra("url", url);
		
		startActivity(intent);
    }

    @Override
    protected Dialog onCreateDialog(int id) 
    {
        Dialog dialog;
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        switch(id) 
        {
        case DIALOG_ADD_ID:
        	
        	final EditText input = new EditText(this);
        	input.setSingleLine();
        	input.setInputType(InputType.TYPE_TEXT_VARIATION_URI);
        	builder.setTitle("Add Url");
        	builder.setMessage("Please, type the url to add:");
        	builder.setView(input);
        	builder.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
        	
        		public void onClick(DialogInterface dialog, int whichButton) {
        			String value = input.getText().toString().trim();
        			input.setText("");
        			if(value.length() > 0)
        			{
        				PlayerView.this.addNewUrl(value);
        			}
        		}
        	});
        	
        	builder.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
        		public void onClick(DialogInterface dialog, int whichButton) {
        			dialog.cancel();
        		} 
        	});
      
        	dialog = builder.create();

            break;
            
        case DIALOG_PLAYLAST_ALERT_ID:
        	builder.setMessage("Do you want to play this video now?")
            .setCancelable(true)
            .setPositiveButton("Yes", new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int id) {
                     PlayerView.this.playUrl(PlayerView.this.mLastUrlAdded);
                }
            })
            .setNegativeButton("No", new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int id) {
                     dialog.cancel();
                }
            });
     
        	dialog = builder.create();
        	break;
        	
        	
        case DIALOG_ABOUT_ID:
        	builder.setTitle("Android Player");
        	builder.setMessage("SDK Version: " + VideoPlayerView.VERSION);
        	builder.setIcon(android.R.drawable.ic_menu_info_details);
        	builder.setCancelable(true);
        	builder.setNegativeButton("Close", new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int id) {
                     dialog.cancel();
                }
            });
        	dialog = builder.create();
        	break;
       
        default:
            dialog = null;
        }
        return dialog;
    }
    
    @Override
    protected void onListItemClick(ListView l, View v, int position, long id) 
    {
    	TextView textView = (TextView) v.findViewById(R.id.list_url);
    	String sUrl = textView.getText().toString();    	
    	playUrl(sUrl);
    }
    
    @Override 
    public void onCreateContextMenu(android.view.ContextMenu menu, View v, android.view.ContextMenu.ContextMenuInfo menuInfo) 
    {
    	AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) menuInfo;
    
    	TextView textView = (TextView) info.targetView.findViewById(R.id.list_text);
    	String sTitle = textView.getText().toString();
    	if(sTitle.contains("/"))
    		sTitle = sTitle.substring(sTitle.lastIndexOf("/"));
    	
    	menu.setHeaderTitle(sTitle);
    	menu.add(0, MenuPlay, 0, "Play");
    	menu.add(0, MenuCopyUrl, 1, "Copy Url");
        menu.add(0, MenuDelete, 2, "Remove");
    }
    
    @Override public boolean onContextItemSelected(MenuItem item) 
    {
    	AdapterView.AdapterContextMenuInfo info = (AdapterView.AdapterContextMenuInfo) item.getMenuInfo();
        
    	TextView textView = (TextView) info.targetView.findViewById(R.id.list_url);
    	String sUrl = textView.getText().toString();
        if(item.getItemId() == MenuDelete)
        {
	    	// Remove from the database
        	mDB.removeEntryByUrl(sUrl);
        	
            // Refresh the list view
            refreshData();
        }
        else if(item.getItemId() == MenuPlay)
        {
        	//((CustomAdapter)getListAdapter()).setDrawableDirty(sUrl);
        	playUrl(sUrl);
        	
        }
        else if(item.getItemId() == MenuCopyUrl)
        {
        	ClipboardManager clipboard = 
        	      (ClipboardManager) getSystemService(CLIPBOARD_SERVICE); 

        	 clipboard.setText(sUrl);
        }
                
     
      return super.onContextItemSelected(item);
    }
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) 
    {
        super.onCreateOptionsMenu(menu);
        
        populateMenu(menu);
        
        return true;
    }
    
    @Override 
    public boolean onOptionsItemSelected(MenuItem item) 
    {
        return applyMenuChoice(item) || super.onOptionsItemSelected(item);
    }
   
    /** create the menu items */
    public void populateMenu(Menu menu) 
    {
      // enable keyb shortcuts, qwerty mode = true means only show keyb shortcuts (not numeric) and vice versa
      // these only show up in context menu, not options menu
      menu.setQwertyMode(true);
      
      MenuItem item1 = menu.add(0, MenuAdd, 0, "Add Url");
      item1.setAlphabeticShortcut('n');
      item1.setIcon(android.R.drawable.ic_menu_add);
      
      MenuItem item2 = menu.add(0, MenuAbout, 0, "About");
      item2.setAlphabeticShortcut('a');
      item2.setIcon(android.R.drawable.ic_menu_info_details);
      
      MenuItem item3 = menu.add(0, MenuConfig, 0, "Config");
      item3.setAlphabeticShortcut('c');
      item3.setIcon(android.R.drawable.ic_menu_preferences);
    }
    
    public boolean applyMenuChoice(MenuItem item) 
    {
      switch (item.getItemId()) 
      {
        case MenuAdd:
            showDialog(DIALOG_ADD_ID);
            return true;
            
        case MenuAbout:
        	showDialog(DIALOG_ABOUT_ID);
        	return true;
        	
        case MenuConfig:
        	Intent iPrefs = new Intent(this, PlayerConfiguration.class);
            startActivityForResult(iPrefs, ACTIVITY_PREFS);
        	return true;
      }
      return false;
    }
	
	
	private class CustomAdapter extends ResourceCursorAdapter 
	{
		private Drawable mDefaultDrawable;
		
        public CustomAdapter(Context context, Cursor cur) 
        {
            super(context, R.layout.listrow, cur);
            mDefaultDrawable = context.getResources().getDrawable(R.drawable.player_play);
        }

        @Override
        public View newView(Context context, Cursor cur, ViewGroup parent) 
        {
            LayoutInflater li = (LayoutInflater)getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            return li.inflate(R.layout.listrow, parent, false);
        }

    

		@Override
		public void bindView(View v, Context context, Cursor cur) 
		{
			ImageView tvListImage = (ImageView) v.findViewById(R.id.list_image);
			TextView tvListText = (TextView)v.findViewById(R.id.list_text);
			TextView tvListUrl = (TextView)v.findViewById(R.id.list_url);

			
            tvListText.setText(cur.getString(PlayerVideosDB.NAME_COLUMN));
            tvListUrl.setText(cur.getString(PlayerVideosDB.URL_COLUMN));
            
            tvListImage.setImageDrawable(getDrawable(cur.getString(PlayerVideosDB.URL_COLUMN)));
		}
		

		
		private Drawable getDrawable(String url)
		{
			return mDefaultDrawable;
		}
    }
}


